Installation — lsm-db 0.1.0 documentation

# Installation

You can use `pip` to install `lsm-db`:

    pip install lsm-db

The project is hosted at https://github.com/coleifer/python-lsm-db and can be installed from source:

    git clone https://github.com/coleifer/python-lsm-db
    cd lsm-db
    python setup.py build
    python setup.py install

Note

`lsm-db` depends on Cython to generate the Python extension. By default, lsm-db ships with a pre-generated C source file, so it is not strictly necessary to install Cython in order to compile `lsm-db`, but you may wish to install Cython to ensure the generated source is compatible with your setup.

After installing lsm-db, you can run the unit tests by executing the `tests` module:

    python tests.py